/*
---------------------------------------------------------------------------
$Revision: 1.1.2.2 $
$Date: 2018/06/28 19:06:16 $

NAME: sea_run_file_set_alter_ddl

TYPE: macro

DESCRIPTION: Run the DDL to change the FILE_SET_MEMBER_CNT column in the
FILE_SET table to a number(12) from a number(6).

SAS VERSION:
9.4

PARAMETERS:
NONE

REQUIREMENTS:

HISTORY:
-----------------------------------------------------------------------------
Copyright (c) 2018, SAS Institute Inc., Cary, NC, USA, All Rights Reserved
------------------------------------------------------------------------------
Run the program in an SEA 4.2 environment from a SAS client.

*/
%macro sea_run_file_set_alter_ddl;
	%sea_etl_macro_vars;
	%sea_ora_connect_info(lib_ext=&sea_ora_lib_ext  
		,reset_lib=Y
		,outdsn=work.libdsn
		,abort=N);

	%if (%sysfunc(libref(&oralib))) > 0 %then
		%do;
			%let retcode=1;

			%rwe_error(msg1=%sysfunc(sasmsg(&msg_dset,_seap01_error,noquote,&oralib)));
			%return;
		%end;

	proc sql;
		&ORA_PASS_THRU_CONNECT;
		EXECUTE(ALTER TABLE FILE_SET modify FILE_SET_MEMBER_CNT NUMBER(12)) by oracle;
	quit;

	proc sql noprint;
		&ora_pass_thru_connect;
		select DATA_PRECISION into :DATA_PRECISION
			from connection to oracle
				(select DATA_PRECISION
					from user_tab_columns b where
						TABLE_NAME='FILE_SET' and COLUMN_NAME='FILE_SET_MEMBER_CNT'
				);
	quit;

	%if &DATA_PRECISION ne 12 %then
		%do;
			%put ERROR:  The ddl did not execute correctly. please try again.;
		%end;
%mend;

%sea_run_file_set_alter_ddl;