/*******************************************************************************
 * $Revision: 1.1.2.4.2.2 $
 * $Date: 2018/07/11 18:14:53 $
 *
 *  Macro:       sea_rwe_pf_reports_data
 *
 *  Author:      Caroline Bahler
 *
 *  Date:        1/10/2017
 *
 *  Purpose:     Generate profile reports
 *
 *  Parameters:  None
 *
 *  Macro Calls: None
 *
 *  History     | ID      | DATE        | COMMENT
 *              | cabahl  | 3/18/2018   | Created
 *              | cabahl  | 6/20/2018   | Updated for RWE 4.3
 *
 *  Notes:
 *
 *******************************************************************************/
/*==================================================================================
Copyright (c) 2018 by SAS Institute Inc., Cary, NC 27513 USA
- All rights reserved
***********************************************************************************/
%macro sea_rwe_pf_reports_data;
 
  %global retcode sea_status_type
          sea_profile_daterange_ds
          sea_profile_stats_ds
          sea_profile_values_ds
          sea_profile_pointer_ds
          sea_profile_pqs_tables_ds
          sea_profile_pqs_fields_ds
          sea_profile_pqs_values_ds
          sea_profile_age_distn_ds
          ;
  %let retcode=0;

  /* Assign SEA libraries */
  %let haf_macro_nm=_VA_REPORT_;
  %sea_adm_allocate_libraries;

  /*
   Library macro variables assigned:
   SEA_DM_LIBREF
   SEA_EPI_LIBREF
   SEA_CLAIMLIB_LIBREF
   SEA_PA_LIBREF
   SEA_RA_LIBREF
   SEA_RPTMART_LIBREF
   SEA_TEMP_LIBREF
  */

  %let sea_profile_pqs_fields_ds=&sea_input_libref..meta_pqs_field;
  %let sea_profile_pqs_tables_ds=&sea_input_libref..meta_pqs_table;
  %let sea_profile_pqs_values_ds=&sea_input_libref..meta_pqs_value;
  %let sea_profile_pqs_field_group_ds=&sea_input_libref..meta_pqs_field_group;
  %let sea_profile_age_distn_ds=&sea_input_libref..meta_profile_age_distn;
  %let sea_profile_values_ds=&sea_input_libref..meta_summary_values;
  %let sea_profile_stats_ds=&sea_input_libref..meta_summary_stats;

  proc sql noprint;
    select kstrip(file_set_nm) as name
      into :haf_fileset_name
      from &sea_dm_libref..file_set
     where file_set_id="&haf_new_fileset_id";
  quit;

  %let member_info=N;

  %rwe_pf_reports_data;

  %if &retcode=1 %then %GOTO ERROREXIT;

  /*  The report macros reset the LS option so capture it now to reset to original  */
  %let lsOpt=%sysfunc(getoption(linesize));
 
  /*  Run reports  - move to separate jobs for rwe */
  %let dateOption=%sysfunc(getoption(date));
  ods select all;
  ods _all_ close;  
  
  %rwe_pf_html_reports(rptPath=%nrbquote(&haf_input_folder)
                      ,sea_export=&sea_export);
 
  ods select all;
  ods _all_ close;

  %if &retcode=1 %then %GOTO ERROREXIT;
  
  %rwe_pf_pdf_reports(rptPath=%nrbquote(&haf_input_folder)
                     ,sea_export=&sea_export);
  
  ods select all;
  ods _all_ close;

  %if &retcode=1 %then %GOTO ERROREXIT;
  
  %rwe_pf_rtf_reports(rptPath=%nrbquote(&haf_input_folder)
                     ,sea_export=&sea_export);
  
  ods select all;
  ods _all_ close;

  %if &retcode=1 %then %GOTO ERROREXIT;  
  
  %rwe_pf_png_reports(rptPath=%nrbquote(&haf_input_folder));
  
  /*  Reset linesize  */
  options ls=&lsOpt orientation=portrait;
  ods select all;
  ods _all_ close;

  %if &retcode=1 %then %GOTO ERROREXIT;
 
  %ERROREXIT:
    %if &retcode=1 %then  %let sea_status_type=ERROR;

%mend;
 
